@@ -60,7 +60,8 @@ void serv_login(struct aim_user *user)
 #endif
 
 	if (p->login) {
-		if (!strlen(user->password) && !(p->options & OPT_PROTO_NO_PASSWORD)) {
+		if (!strlen(user->password) && !(p->options & OPT_PROTO_NO_PASSWORD) &&
+			!(p->options & OPT_PROTO_PASSWORD_OPTIONAL)) {
 			do_error_dialog(_("Please enter your password"), NULL, GAIM_ERROR);
 			return;
 		}
@@ -181,6 +182,13 @@ int serv_send_typing(struct gaim_connection *g, char *name, int typing) {
 	else return 0;
 }
 
+struct queued_away_response {
+	char name[80];
+	time_t sent_away;
+};
+
+struct queued_away_response *find_queued_away_response_by_name(char *name);
+
 int serv_send_im(struct gaim_connection *gc, char *name, char *message, int len, int flags)
 {
 	int val = -EINVAL;
@@ -191,6 +199,21 @@ int serv_send_im(struct gaim_connection *gc, char *name, char *message, int len,
 	if (!(flags & IM_FLAG_AWAY))
 		serv_touch_idle(gc);
 
+	if (gc->away && away_options & OPT_AWAY_DELAY_IN_USE &&
+			!(away_options & OPT_AWAY_NO_AUTO_RESP)) {
+		time_t t;
+		struct queued_away_response *qar;
+		time(&t);
+		qar = find_queued_away_response_by_name(name);
+		if (!qar) {
+			qar = (struct queued_away_response *)g_new0(struct queued_away_response, 1);
+			g_snprintf(qar->name, sizeof(qar->name), "%s", name);
+			qar->sent_away = 0;
+			away_time_queue = g_slist_append(away_time_queue, qar);
+		}
+		qar->sent_away = t;
+	}
+
 	if (cnv && cnv->type_again_timeout)
 		gtk_timeout_remove(cnv->type_again_timeout);
 
@@ -499,11 +522,6 @@ int find_queue_total_by_name(char *name)
 	return i;
 }
 
-struct queued_away_response {
-	char name[80];
-	time_t sent_away;
-};
-
 struct queued_away_response *find_queued_away_response_by_name(char *name)
 {
 	GSList *templist;
@@ -576,6 +594,7 @@ void serv_got_im(struct gaim_connection *gc, char *name, char *message, guint32
 		message = g_memdup(message, len);
 	}
 
+#if 0
 	/* TiK, using TOC, sends an automated message in order to get your away message. Now,
 	 * this is one of the biggest hacks I think I've seen. But, in order to be nice to
 	 * TiK, we're going to give users the option to ignore it. */
@@ -588,6 +607,7 @@ void serv_got_im(struct gaim_connection *gc, char *name, char *message, guint32
 		g_free(message);
 		return;
 	}
+#endif
 
 	/* if you can't figure this out, stop reading right now.
 	 * "we're not worthy! we're not worthy!" */
